import { expect } from 'chai';
import * as buildTree from './build-tree';

const fixtures = `${__dirname}/../../fixtures/precinct`;

describe('buildTree', () => {
  describe('getDependencyTree', () => {
    const dependencyTreeParams = {
      baseDir: '.',
      consumerPath: __dirname,
      filePaths: [],
      bindingPrefix: '@bit',
      resolveModulesConfig: undefined
    };
    it('when no files are passed should return an empty tree', async () => {
      const results = await buildTree.getDependencyTree(dependencyTreeParams);
      expect(results).to.deep.equal({ tree: {} });
    });
    it('when unsupported files are passed should return them with no dependencies', async () => {
      dependencyTreeParams.filePaths = ['a.pdf'];
      const results = await buildTree.getDependencyTree(dependencyTreeParams);
      expect(results.tree).to.deep.equal({ 'a.pdf': {} });
    });
    it('when supported and unsupported files are passed should return them all', async () => {
      dependencyTreeParams.filePaths = ['a.pdf', `${fixtures}/es6.js`];
      const results = await buildTree.getDependencyTree(dependencyTreeParams);
      expect(results.tree).to.have.property('a.pdf');
      expect(results.tree).to.have.property('fixtures/precinct/es6.js');
    });
  });
});
